==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncSetListBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SelectorSyncSetListBuilder extends SelectorSyncSetListFluentImpl<SelectorSyncSetListBuilder> implements VisitableBuilder<SelectorSyncSetList,SelectorSyncSetListBuilder>{
  public SelectorSyncSetListBuilder() {
    this(false);
  }
  public SelectorSyncSetListBuilder(Boolean validationEnabled) {
    this(new SelectorSyncSetList(), validationEnabled);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetListFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SelectorSyncSetList(), validationEnabled);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetListFluent<?> fluent,SelectorSyncSetList instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetListFluent<?> fluent,SelectorSyncSetList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetList instance) {
    this(instance,false);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SelectorSyncSetListFluent<?> fluent;
  Boolean validationEnabled;
  public SelectorSyncSetList build() {
    SelectorSyncSetList buildable = new SelectorSyncSetList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncSetListBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SelectorSyncSetListBuilder extends SelectorSyncSetListFluent<SelectorSyncSetListBuilder> implements VisitableBuilder<SelectorSyncSetList,SelectorSyncSetListBuilder>{
  public SelectorSyncSetListBuilder() {
    this(false);
  }
  public SelectorSyncSetListBuilder(Boolean validationEnabled) {
    this(new SelectorSyncSetList(), validationEnabled);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetListFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SelectorSyncSetList(), validationEnabled);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetListFluent<?> fluent,SelectorSyncSetList instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetListFluent<?> fluent,SelectorSyncSetList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new SelectorSyncSetList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetList instance) {
    this(instance,false);
  }
  public SelectorSyncSetListBuilder(SelectorSyncSetList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new SelectorSyncSetList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SelectorSyncSetListFluent<?> fluent;
  Boolean validationEnabled;
  public SelectorSyncSetList build() {
    SelectorSyncSetList buildable = new SelectorSyncSetList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
